# Coinmarketcap Parsing

Python3 scrap all the related information about different cryptocurrencies around the [Coinmarketcap](https://coinmarketcap.com/) 
This package is for getting all the paragraphs related to specific cryptocurrencies.
If you have problems with packages 'requests' and 'beautifulSoup', you should install it from [requests](https://pypi.org/project/requests/), [beautifulSoup](https://www.crummy.com/software/BeautifulSoup/bs4/doc/)

### Installation
PyPI
```bash
pip install package_crypto==0.0.2
```
### Usage

```python
from package_crypto.cryptomarket import Pars
result = Pars()
```

